@@ -7,13 +7,13 @@ class Provider(BaseProvider):
     """
 
     vat_id_formats = (
-        'FR?? #########',
-        'FR## #########',
-        'FR?# #########',
-        'FR#? #########',
+        "FR?? #########",
+        "FR## #########",
+        "FR?# #########",
+        "FR#? #########",
     )
 
-    def vat_id(self):
+    def vat_id(self) -> str:
         """
         http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
         :return: a random French VAT ID
